/*
 File:		TaskWrapper.h

 Description: 	This class is a generalized process handling class that makes asynchronous interaction with an NSTask easier.  There is also a protocol designed to work in conjunction with the TaskWrapper class; your process controller should conform to this protocol.  TaskWrapper objects are one-shot (since NSTask is one-shot); if you need to run a task more than once, destroy/create new TaskWrapper objects.

 Author:		EP & MCF

 Copyright: 	 Copyright 2001 Apple Computer, Inc. All rights reserved.

 */


#import <Foundation/Foundation.h>

@protocol TaskWrapperDelegate

- (void)appendOutput:(NSData *)output;
- (void)appendError:(NSString *)output;
- (void)processStarted;
- (void)processFinished;
- (void)setTask:(id)inTask;

@end

@interface TaskWrapper : NSObject {
    NSTask 			*_task;
    id				_delegate;
    NSArray			*_arguments;
	BOOL			_ownDelegate	;
}

- (id)initWithDelegate:(id)delegate arguments:(NSArray *)args;
- (void)retainDelegate	;

- (void) startProcess;
- (void) stopProcess;

@end

